#pragma rtGlobals=3		// Use modern global access method and strict wave access.

Menu "DiracSingleProfile"
"StorageMatrix" //Create the matrices where the fit results can be stored NB: use only at the beginning of the analysis (just for the first cone)
"StoreCentrePosition" //Positioning the cursorA on the cone center we store the center position
"MeasureAngle" //Measure the angle of the line (respect to the horizontal) used to extract the WF
"PutCursorInCentre" //Put the cursor in the cone center (position stored before)
//"PrepareCursorForWF" //Prepare the cursors in the right position to extract the WF
//"Extract_WF" //Extract the WF, the width is already initialized 
"SelectRange" //Select the range in which you perform the fit of the WF
"FitLPwithGaussian" //Fit the line profile with two gaussians, the values obtained are used as start parameters
"FitWF" //Fit the entire WF (both the branches of the cone) with two gaussians 
"FitWF_SinglePeak" //Fit only one branch at the time, with a gaussian function 
"ResultsFromFit" //Show the results from the fit
"DiracPointfromXsingle" //Find the dirac point from the fit results using a linear fit
"CalculateED" //Calculate the dirac energy (before you need to fill the matrix of the fermi levels (FL is not the same across the spectrum)
"WeightedAverages" //Weighted averages of FV and ED taking in account all cones
"DisplayAllEDandVF" //Display the results of all cones, attaching the value of the weighted average plus the associated error
"ResetWaves" //Reset the temporary matrices to start with another cone
End

///////////////////////////////////////////////////////////////////////------------------------------------------------------///////////////////////////////////////////////////////////////////////
Proc StorageMatrix()
	 DRC_StorageMatrix()
End
// 3 matrices are available: 
//	 ==> Storage matrix: all the results from all cones are storaged
//	 ==> Fermi matrix: For each cone we store the values of the Fermi levels (FL) at different positions of the WF
//	 ==> Temp Fermi Matrix: For simplicity when we are working on a particular cone we use this matrix to store the correspondent values of FL and the associated error,
//		  then, at the end, we have to copy them into Fermi matrix (just select the line, copy and paste)

Proc MeasureAngle()
	DRC_MeasureAngle()
End
// To measure the angle put the crsA and crsB on the center of the two adjacent cones 

Proc PutCursorInCentre()
	DRC_csr2Centre()
	DRC_putCursorsForWF()
	DRC_DiracInizialize()
	DRC_extract_WF()
End


//Proc PrepareCursorForWF()
//	DRC_putCursorsForWF()
//End

//Proc Extract_WF()
// 	DRC_DiracInizialize()
//	DRC_extract_WF()
// End
// Each time you extract a WF the program increments the cone number of a unity, check each time if the number is correct. For the first cone you have to insert the file name
// which will be stored for the next times.

Proc SelectRange()
	 DRC_LineRrange()
End
// SelectRange is used to select the boundaries of the WF when we are performing a fit of the WF with gaussian functions. First put the cursors (A&B) following the linear dispersion on the left, 
// (be carefull to leave enough space because is mandatory to fit the tail of the gaussian), then we have to do the same thing on the right. At the end we put the CrsA in the center of the cone,
// we use this to fit one peak at the time.

Proc FitLPwithGaussian()
	 DRC_GfitInitialize()
End
// First we extract one single profile parallel to the bottom of the WF then we use "FitLPwithGaussian" to fit it, obtaining the start parameters for the fit of entire WF

Proc FitWF()
	 DRC_fitSeriesWithRange()
End
// To fit at the same time both peaks we use "FitWF" otherwise, to fit one peak at the time we use "FitWF_SinglePeak"

Proc FitWF_SinglePeak()
	 DRC_fitSeriesWRSinglePeak()
End
// With this procedure the error become worst but the fit is able to follow better the main peak (useful when the spectrum is broadened)

Proc ResultsFromFit()
	 DRC_extractResultsSP()
End
// We extract the results from the gaussian and we plot them, we can choose which results we want to plot: either results from "FitWF" or "FitWF_SinglePeak"

Proc DiracPointfromXsingle()
	 DRC_SingleDiracPointfromX()
End
// To calculate the position of the dirac point and the relative error bar, the process is iterative because you have to find the region where the spectrum is linear, if you want to compare the results from
// "FitWF" to "FitWF_SinglePeak" you can select the option "use the last range" from the popup window.

Proc CalculateED()
	 DRC_CalcED()
End
// This procedure calculate the ED, first it calculates the weighted average of the correspondent FL and then prints out the value of ED and storage it on the main matrix

Proc WeightedAverages()
	 DRC_WeightedAverages()
End
// This procedure is usually used when all the cones have been analyzed, because it returns the weighted average of ED (and VF) + error, taking in account all the cones

Proc DisplayAllEDandVF()
	 DRC_displayAllDiracEnergy()
End
// Before using "DisplayAllEDandVF" we must use "WeightedAverages"

Proc ResetWaves()
	 DRC_Reset()
End
///////////////////////////////////////////////////////////////////////------------------------------------------------------///////////////////////////////////////////////////////////////////////

Proc StoreCentrePosition()
	String dfStr=SIS_getDataFolderName()
	SetDataFolder root:$(dfStr)
	variable pA=pcsr(A)
	variable qA=qcsr(A)
	Variable/G diracPospA=pA
	Variable/G diracPosqA=qA
	string storePos = "(x_center;y_center): " +"("+ num2str(pA) + ";" + num2str(qA) + ") px"
	print storePos
End

///////////////////////////////////////////////////////////////////////------------------------------------------------------///////////////////////////////////////////////////////////////////////

Function DRC_putCursorsForWF()
	// data folder and stack
	String dfStr=SIS_getDataFolderName()
	SetDataFolder root:$(dfStr)
	String stackStr=SIS_getImageStackName()
	String winNameStr=SIS_getWinName()
	// input
	NVAR rotangle=root:SIS:rotangle
	variable halfWidth=100
	prompt halfWidth, "Distance from csrA"
	variable angle=rotangle
	prompt angle, "angle from horizontal"
	variable rotation=1
	Prompt rotation, "Rotate 90 deg", popup "no; yes"
	doPrompt "input put cursors for Dirac", halfWidth, angle, rotation
	if (V_flag ==0)
		if (stringMatch(num2Str(pcsr(A)),"NaN")!=1)
			variable p1=pcsr(A)
			variable q1=qcsr(A)
			if (rotation == 1)
				variable newp1=p1+round(halfWidth*cos(angle*Pi/180))
				variable newq1=q1-round(halfWidth*sin(angle*Pi/180))
				variable newp2=p1-round(halfWidth*cos(angle*Pi/180))
				variable newq2=q1+round(halfWidth*sin(angle*Pi/180))
				Cursor/P/I B $stackStr,newp2,newq2
				Cursor/P/I A$stackStr,newp1,newq1
			else
				variable newp1r=p1+round(halfWidth*cos((angle+90)*Pi/180))
				variable newq1r=q1-round(halfWidth*sin((angle+90)*Pi/180))
				variable newp2r=p1-round(halfWidth*cos((angle+90)*Pi/180))
				variable newq2r=q1+round(halfWidth*sin((angle+90)*Pi/180))
				Cursor/P/I B $stackStr,newp2r,newq2r
				Cursor/P/I A$stackStr,newp1r,newq1r
			endif
		endif
	endif
end

///////////////////////////////////////////////////////////////////////------------------------------------------------------///////////////////////////////////////////////////////////////////////

Function DRC_measureAngle()
	String ctrlname
	NVAR rotangle=root:SIS:rotangle
	SetDataFolder root:SIS
	// data folder
	String dfStr=SIS_getDataFolderName()
	SetDataFolder root:$(dfStr)
	String stackStr=SIS_getImageStackName()	
	NVAR kcalib=root:SIS:kcalib
	//
	variable suggestedAngle
	if (strlen(csrInfo(A))>0 & strlen(csrInfo(B))>0)
		if (stringMatch(num2Str(pcsr(A)),"NaN")!=1 && stringMatch(num2Str(pcsr(B)),"NaN")!=1)
			variable p1=pcsr(A)
			variable p2=pcsr(B)
			variable q1=qcsr(A)
			variable q2=qcsr(B)
			suggestedAngle=round(atan(abs(q2-q1)/abs(p2-p1))*1800/Pi)/10

			variable num = (q2-q1), den = (p2-p1)
			//string stampa = "numeratore: " + num2str(num) + " denominatore: " + num2str(den)
			//print stampa
			 	if(num*den > 0)
			 		suggestedAngle = suggestedAngle*(-1)
			 	endif
		endif
	else
		Print "put cursors on screen please"
	endif
	rotangle = suggestedAngle
	string angle = "angle measured: " + num2str(suggestedAngle) + ""
	print angle
end

///////////////////////////////////////////////////////////////////////------------------------------------------------------///////////////////////////////////////////////////////////////////////

Function DRC_csr2Centre()
	String dfStr=SIS_getDataFolderName()
	SetDataFolder root:$(dfStr)
	NVAR diracPospA=root:$(dfStr):diracPospA
	NVAR diracPosqA=root:$(dfStr):diracPosqA
	String stackStr=SIS_getImageStackName()	
	Cursor/P/I A $stackStr,diracPospA,diracPosqA
End

///////////////////////////////////////////////////////////////////////------------------------------------------------------///////////////////////////////////////////////////////////////////////

Function DRC_extract_WF()

//  globals
	NVAR lastcrsAp = root:SIS:lastcrsAp
	NVAR lastcrsBp = root:SIS:lastcrsBp
	NVAR lastcrsAq = root:SIS:lastcrsAq
	NVAR lastcrsBq = root:SIS:lastcrsBq
	NVAR lastprowidth = root:SIS:lastprowidth
	// data folder and stack
	String dfStr=SIS_getDataFolderName()
	SetDataFolder root:$(dfStr)
	String stackStr=SIS_getImageStackName()
	String winNameStr=SIS_getWinName()
	wave M_ImageLineProfile
	if (dimSize($stackStr,2)>1) // if stack then
		// profile width
		variable prowidth=lastprowidth
		prompt prowidth, "profile width"
		doPrompt "input stack watefall" prowidth
		if(V_Flag==0)
			lastprowidth=prowidth
			// cursors
			if (stringMatch(num2Str(pcsr(A)),"NaN")!=1 && stringMatch(num2Str(pcsr(B)),"NaN")!=1)
				variable p1=pcsr(A)
				variable p2=pcsr(B)
				variable q1=qcsr(A)
				variable q2=qcsr(B)
				lastcrsAp=p1
				lastcrsBp=p2
				lastcrsAq=q1
				lastcrsBq=q2
			else
				p1= lastcrsAp
				p2 = lastcrsBp
				q1= lastcrsAq
				q2 = lastcrsBq
			endif
			// draw line
			SetDrawLayer UserFront
			setDrawEnv xcoord= top,ycoord= left,linefgc= (65280,0,0)		
			DrawLine p1,q1,p2,q2
			// calc profile
			variable npixels=round(sqrt((p2-p1)^2+(q2-q1)^2 ))+1
			variable theta=-atan2((q2-q1),(p2-p1))
			make/n=(npixels)/o ptmp,qtmp
			ptmp[]=p1+(p2-p1)/(npixels-1)*p 
			qtmp[]=q1+(q2-q1)/(npixels-1)*p  
			// show in WF
			variable nr=dimSize($stackStr,2)
			ImageLineProfile/P=-2 srcWave=$stackStr, xWave=ptmp, yWave=qtmp, width=prowidth
			String wfStr=stackStr+"_WF"
			String graphStr="WF"+stackStr
			// make p and q waves
			variable np=dimsize(M_ImageLineProfile,0)
			variable nq=dimsize(M_ImageLineProfile,1)
			String pStr="WF"+dfStr+"_P"
			String qStr="WF"+dfStr+"_Q"
			Make/N=(np+1)/o $pStr
			Make/N=(nq+1)/o $qStr
			wave wp=$pStr
			wave wq=$qStr
			wp=p 
			wq=p
			duplicate/o M_ImageLineProfile $wfstr
			SIS_xyImageToFront(graphStr,wfStr,pStr,qStr) 
			// control bar & buttons
			ControlBar 41
			button xToPixelButton, proc=PROI_xtoPixel ,pos={1,1} , size={79,18}, title="x to pixel" 
			button xToNanoButton, proc=PROI_xtoNano ,pos={81,1} , size={79,18}, title="x to nm" 
			button xtoKEButton, proc=PROI_xtoKE ,pos={161,1} , size={79,18}, title="x to KE" 
			button xtoBEButton, proc=PROI_xtoBE ,pos={241,1} , size={79,18}, title="x to BE" 
			button xtoKspaceButton, proc=PROI_xtoKspace ,pos={321,1} , size={79,18}, title="x to Kspace" 
			button killButton, proc=PROI_killwaves ,pos={401,1} , size={79,18}, title="kill" 	
			button setScaleLeftAxisButton, proc=PROI_setScaleLeftAxis ,pos={1,21} , size={79,18}, title="left axis"
			button setScaleRightAxisButton, proc=PROI_setScaleRightAxis ,pos={81,21} , size={79,18}, title="right axis"
			button rescaleButton, proc=PROI_rescale_axis ,pos={161,21} , size={79,18}, title="rescale axes" 
			button norm_image_bkgButton, proc=PROI_norm_image_bkg ,pos={241,21} , size={79,18}, title="norm@CRSs" 
			button divide_image_bkgButton, proc=PROI_div_image_crs ,pos={321,21} , size={79,18}, title="div@CRSavg" 
			Label bottom "\\F'Arial'\\Z18Pixels"
			Label left "\\F'Arial'\\Z18Pixels"
			SetAxis/A bottom
			ModifyGraph fSize=12
			ModifyImage $wfStr ctab= {*,*,Terrain,0}
			killwaves qtmp,ptmp
			
		endif
	endif
End

///////////////////////////////////////////////////////////////////////------------------------------------------------------///////////////////////////////////////////////////////////////////////

Function DRC_CalcED() 
	
	String dfStr=SIS_getDataFolderName()
	SetDataFolder root:SIS
	NVAR coneNumber=root:SIS:coneNumber
	wave FM, DM //Fermi and Dirac Matrix
	variable M = coneNumber //select the cone
	variable i, j // sum indices
	variable L, FAv = 0, sigma = 0 //L:is the number of Fermis and their errors, FAv:Fermi Average, sigma:error on FAv
	variable sumWeight = 0 // value of the weighted average
	NVAR diracPospA = root:$(dfStr):diracPospA
	NVAR diracPosqA = root:$(dfStr):diracPosqA
	NVAR rotangle=root:SIS:rotangle
	
	variable tn = 6 //total number of dirac cones
	variable sw
	
	prompt M, "select the cone on which you want to calculate the Dirac Energy"
	doprompt "Initialization of the cone", M
	M = M - 1	
	
	//first we are calculating the weighted average of the Fermi Levels for one particular cone	
		
			L = dimSize(FM,1) - 1 //Igor calculates the number of the column of the matrix if the variable is 1, 0 is for the rows
			//print "number of Fermi levels involved in the average", L/2
			make/O/N=(L/2)/D weightWave = 0, Av
			// perform the calculations of the weights
			for(i=0;i<L/2;i+=1) //i<M Igor stops at M-1, and starts from 0
				if(FM[M][i*2 + 2] == 0)
					weightWave[i] = 0
				else
					weightWave[i] = 1/(FM[M][i*2 + 2])^2
				endif
		
			endfor
		
			sumWeight = sum(weightWave)
	
			for(j=1;j<=L/2;j+=1) //i<M Igor stops at M-1, and starts from 0		
				Av[j-1] = FM[M][j*2 - 1]*weightWave[j-1] 
				//print "FM[M][j*2 - 1]", FM[M][j*2 - 1]
			endfor
	
			FAv = sum(Av)/sumWeight
			sigma = 1/sqrt(sumWeight)		
			//print "weighted average for the Fermi level", FAv, "pm", sigma
			 // I want to storage the results automatically
			DM[5][M] = FAv
			DM[6][M] = sigma
			
	//second we calculate ED
	
	//String dfStr=SIS_getDataFolderName()
	//setDataFolder root:SIS
	
	NVAR EaV = root:SIS:EaV
	NVAR sigma_ed = root:SIS:sigma_ed
	SVAR fName = root:SIS:fName
	NVAR sigma_fV = root:SIS:sigma_fV
	NVAR fV_aV = root:SIS:fV_aV
	variable edShift //difference between dirac energy and fermi level
	variable err_edShift // error on edShift calculated as the sum of the two errors

	variable ymin, ymax //ymin & ymax are used below to display the waves
	make/O/N=(6) temp = NaN, cnw = NaN
	variable ex
	string textb


			edShift = DM[1][M] - DM[5][M]
			DM[7][M] = edShift
			err_edShift = DM[2][M] + DM[6][M]	
			DM[8][M] =err_edShift
			
			string storePos = "(x_center;y_center): " +"("+ num2str(diracPospA) + ";" + num2str(diracPosqA) + ") px " + "angle: " + num2str(rotangle) + ""
			string FermiStr = "Fermi Level @: " + num2str(FAv) + " eV"
			string displ = "Cone: " + num2str(coneNumber) + " ==> E_d - E_f = " + num2str(edShift) + " pm " + num2str(err_edShift) + " eV"
			
			print storePos
			print FermiStr
			print displ
			
	dowindow/F StorageMatrix

SetDataFolder root:$(dfStr)

end

///////////////////////////////////////////////////////////////////////------------------------------------------------------///////////////////////////////////////////////////////////////////////



Function DRC_WeightedAverages()

	SetDataFolder root:SIS
	//NVAR coneNumber=root:SIS:coneNumber
	wave FM, DM //Fermi and Dirac Matrix
	//variable M // M:number of the cone
	variable i, j // sum indexes
	variable L, FAv = 0, sigma = 0 //L:is the number of Fermis and their errors, FAv:Fermi Average, sigma:error on FAv
	//M = coneNumber // the value is initialized somewhere 
	variable sumWeight = 0 // value of the weighted average
	// 
	//prompt M, "Select the Dirac cone"
	variable mode = 1
	prompt mode "weighted averege of: DIRACenergy / FermiVelocity", popup "Dirac Energies;Fermi Velocities"
	doprompt "Weighted average", mode //M,
	//M = M - 1
	variable tn = 6 //total number of dirac cones
	variable sw, var
	
	
	if(V_flag == 0)
	
			if(mode==1)//Dirac energy
				variable/G sigma_Ed, EaV
				make/N=(tn)/O weight_Ed = 0, av_Ed, wEaV
				
				for(i=0;i<tn;i+=1) //qui calcola i pesi
				
					var = numtype(DM[8][i]) // numtype is equal 2 if contains NaN, is 0 if it is a number
										  // lo uso per escludere il caso in cui abbiamo degli 0 al denominatore o dei NaN
										
					if(var == 2 || DM[8][i] == 0)						
						weight_Ed[i] = 0
					else	
						weight_Ed[i] = 1/(DM[8][i])^2							
					endif
					
				//print "weight_Ed[i]",i, weight_Ed[i], "var", var
								
				endfor
				
				sw = sum(weight_Ed)
				//print "sw", sw
			
				for(i=0;i<tn;i+=1) //i<M Igor stops at M-1, and starts from 0	
					var = numtype(DM[7][i]) // numtype is equal 2 if contains NaN.
					
					if(var == 2)	
						av_Ed[i] = 0
					else
						av_Ed[i] = DM[7][i]*weight_Ed[i] 						
					endif
					//print "i_media",i, av_Ed[i], "DM[7][i]", DM[7][i]
				endfor
		
				EaV = sum(Av_Ed)/sw
				sigma_Ed = 1/sqrt(sw)
				string stampa = "Weighted average ED: " + num2str(EaV) + " pm " + num2str(sigma_ed) + " eV"
				print stampa
				wEaV = EaV 
		
			endif
		
		if(mode==2)//Fermi velocities
			variable/G sigma_fV, fV_aV
			make/N=(tn)/O weight_fV = 0, w_av_fV, w_fVaV
			
			for(i=0;i<tn;i+=1)
			
			var = numtype(DM[4][i]) 
			
				if(var == 2 || DM[4][i] == 0)
					weight_fV[i] = 0
				else
					weight_fV[i] = 1/(DM[4][i])^2
				endif
				//print "i",i, weight_fV[i]
			endfor
			
			sw = sum(weight_fV)
			//print "sw", sw
			
			for(i=0;i<tn;i+=1) //i<M Igor stops at M-1, and starts from 0	
			
					var = numtype(DM[3][i]) // numtype is equal 2 if contains NaN.
					
					if(var == 2)	
						w_av_fV[i] = 0
					else
						w_av_fV[i] = DM[3][i]*weight_fV[i] 						
					endif
				
				//print "i secondo ciclo", i, "w_av_fV[i]",w_av_fV[i]
			endfor
		
			fV_aV = sum(w_av_fV)/sw
			sigma_fV = 1/sqrt(sw)
			
			stampa = "Weighted average VF: " + num2str(fV_aV) + " pm " + num2str(sigma_fV) + " m/s"
			print stampa
			//print "media pesata VF:",fV_aV,"pm", sigma_fV
			w_fVaV = fV_aV 
		
		endif


	endif	
End

///////------------------///////------------------///////------------------///////------------------///////------------------///////------------------///////------------------///////

Function DRC_StorageMatrix()
	String dfStr=SIS_getDataFolderName()
	SetDataFolder root:SIS
	variable M, N //M:rows N:columns
	//variable i, j //i:rows j:column
	M = 6
	variable mat = 4 //logic variable to select the matrix that I want to create, setted on "All"
	// I want to create a matrix where I can storage all rthe Fermi Level, then is easier to perform the average
	prompt M, "How many cones you want to analyze?"
	prompt mat, "Select the matrix", popup "Fermi Matrix;Storage Matrix;Temporary matrix for Fermi levels;All"
	doprompt "Create the storage matrix" M, mat 
	
	if (V_Flag==0)	
		
		if(mat == 1)
			DRC_FermiMatrix(M)
		endif	
		if (mat == 2)
			DRC_AllStoreMatrix(M)
		endif
		if(mat == 3)
			DRC_tempFM()
		endif					
		if(mat == 4)
			DRC_FermiMatrix(M)
			DRC_AllStoreMatrix(M)
			DRC_tempFM()
		endif	
			
	endif

End

///////------------------///////------------------///////------------------///////------------------///////------------------///////------------------///////------------------///////


Function DRC_SingleDiracPointfromX()
	// data folder
	String dfStr=SIS_getDataFolderName()
	String winStr=SIS_getWinName()
	SetDataFolder root:$(dfStr)
	// input
	NVAR kcalib=root:SIS:kcalib
	NVAR coneNumber=root:SIS:coneNumber
	
	variable ft
	variable match = StringMatch(winStr,"rt_*")
	//print "match" , match,"winStr", winStr
	if(match == 0)
		ft = 1
	else
		ft = 2
	endif
	
	prompt ft, "what wave you want to fit", popup "wave F; wave rt_F"
	String xStr
	Prompt xStr, "enter K wave",popup WaveList("STV*",";","")
	variable errormode=2
	Prompt errorMode, "Error Mode", popup "auto; input errors"
	variable intercepterror=2
	Prompt intercepterror, "Consider intercept error", popup "no; yes"
	variable calib=kcalib
	Prompt calib,"k-space calibration"	
	variable opMode = 1
	prompt opMode, "New Range / Last Range", popup "Select the range;Use last range"
	variable M =coneNumber //I'm using a global variable setted at the beginning
	Prompt M, "insert the number of the cone"
	doprompt "select the waves", ft,xStr,errorMode,intercepterror,calib,opMode,M
	
	if(V_flag==0)
		coneNumber = M
		string ref
	
		if(ft == 1)
			string f1= "F*_9", e1 = "E*_9"
			string f2= "F*_14", e2 = "E*_14"
			ref = "FR"
		else
			ref = "rt_FR"
			f1 = "rt_F*_9", e1 = "rt_E*_9"
			f2 = "rt_F*_14", e2 = "rt_E*_14"
		endif
		
			String y1Str = WaveList(f1,";","") 
			y1Str = stringFromList(0, y1Str)
			String y2Str = WaveList(f2,";","") 
			y2Str = stringFromList(0, y2Str)
			String errStr1 = WaveList(e1,";","") 
			errStr1 = StringFromList(0, errStr1)
			String errStr2 = WaveList(e2,";","") 	
			errStr2 = StringFromList(0, errStr2)

		print "y1Str", y1Str, "y2Str", y2Str
		print "errStr1", errStr1, "errStr2", errStr2
	
		if (V_Flag==0)
			kcalib=calib
			make/n=2/o W_coef,W_sigma,W_ParamConfidenceInterval
			wave W_coef,W_sigma,W_ParamConfidenceInterval
			// auto-estimate errors

		Variable/G st_pcsrA_9, st_pcsrB_9, st_pcsrA_14, st_pcsrB_14
		string opModeStr
	if(opMode==1)
		ModifyGraph mode=0
		//ErrorBars $y1Str OFF 
		SIS_PauseForCursors(winStr,"Adjust crs A and B on the _9 wave")
				st_pcsrA_9 = pcsr(A)
				st_pcsrB_9 = pcsr(B)
		opModeStr = "NEW Range of: " + y1Str + " from: " + num2str(st_pcsrA_9) + "px to " + num2str(st_pcsrB_9) + "px"
		print opModeStr
	endif

	if(opMode == 2) // first function fit $y1Str
		Cursor/P A $y1Str st_pcsrA_9
		Cursor/P B $y1Str st_pcsrB_9
		doUpdate
		opModeStr = "LAST Range of: "+ y1Str +" from: " + num2str(st_pcsrA_9) + "px to " + num2str(st_pcsrB_9) + "px"
		print opModeStr
	endif

	Tag/C/B=(65535,65535,65535) /N=text2/F=0  $y1Str, st_pcsrA_9,"S"
	Tag/C/B=(65535,65535,65535) /N=text3/F=0  $y1Str, st_pcsrB_9,"St"
	doUpdate

	/////////////////////////////////////////////////////////
		// auto estimate errors	
		CurveFit/NTHR=0/ODR=1/Q/G line  $y1Str[pcsr(A),pcsr(B)] /X=$xStr /D 
		variable a0_1=W_coef[0]
		variable a1_1=W_coef[1]
		duplicate/o $y1Str diff
		duplicate/o $xStr xx
		diff=diff[p]-(a0_1+a1_1*xx[p])
		Wavestats/R=(pcsr(A),pcsr(B))/Q diff
		diff=V_rms 
		// calculate errors
		//String errStr1="E"+y1str[1,strlen(y1Str)]
		wave we1 = $errStr1
		if (errorMode == 2)
			diff = we1
		endif
		// fit
		CurveFit/NTHR=0/Q line $y1Str[pcsr(A),pcsr(B)] /X=$xStr /D /W=diff /I=1 /D/F={0.683000, 4}
		// results
		a0_1=W_coef[0]
		a1_1=W_coef[1]
		// errors
		variable sig0_1=W_ParamConfidenceInterval[0]
		variable sig1_1=W_ParamConfidenceInterval[1]
		// plot
		String fit1Str="fit_"+y1Str		
		wavestats/Q $xStr
		variable xl=V_min
		variable xr=V_max
		SetScale/I x xl,xr,"",$fit1Str
		wave wf1=$fit1Str
		wf1=a0_1+a1_1*x

if(opMode==1)
	ModifyGraph mode=0
	ErrorBars $y2Str OFF 
	DoUpdate
	SIS_PauseForCursors(winStr,"Adjust crs A and B on the _14 wave")	
			st_pcsrA_14 = pcsr(A)
			st_pcsrB_14 = pcsr(B)	
	opModeStr = "NEW Range of: " + y2Str + " from: " + num2str(st_pcsrA_14) + "px to " + num2str(st_pcsrB_14) + "px"
	print opModeStr
endif

if(opMode == 2) //second function fit $y2Str
	Cursor/P A $y2Str st_pcsrA_14
	Cursor/P B $y2Str st_pcsrB_14
	doUpdate
	opModeStr = "LAST Range of: " + y2Str + " from: " + num2str(st_pcsrA_14) + "px to " + num2str(st_pcsrB_14) + "px"
	print opModeStr
endif

Tag/C/N=text4/B=(65535,65535,65535)/F=0  $y2Str, st_pcsrA_14,"S"
Tag/C/N=text5/B=(65535,65535,65535)/F=0  $y2Str, st_pcsrB_14,"St"
doUpdate

		/////////////////
		CurveFit/NTHR=0/ODR=1/Q/G line  $y2Str[pcsr(A),pcsr(B)] /X=$xStr /D 
		variable a0_2=W_coef[0]
		variable a1_2=W_coef[1]
		duplicate/o $y2Str diff
		duplicate/o $xStr xx
		diff=diff[p]-(a0_2+a1_2*xx[p])
		Wavestats/R=(pcsr(A),pcsr(B))/Q diff
		diff=V_rms
		// calculate errors from fit
		//String errStr2="E"+y2str[1,strlen(y2Str)]
		wave we2 = $errStr2
		if (errorMode == 2)
			diff = we2
		endif
		//fit
		CurveFit/NTHR=0/Q line  $y2Str[pcsr(A),pcsr(B)] /X=$xStr /D /W=diff /I=1 /D /F={0.683000, 4}
		// results
		a0_2=W_coef[0]
		a1_2=W_coef[1]
		string angCoeff_1, angCoeff_2
		angcoeff_1 = y1str + " = "+ num2str(a0_1) + " + " + num2str(a1_1) + "*x_1"
		angcoeff_2 = y2str + " = "+ num2str(a0_2) + " + " + num2str(a1_2) + "*x_2"
		//print the line equations
		Print angcoeff_1
		Print angcoeff_2
		// error
		variable sig0_2=W_ParamConfidenceInterval[0]
		variable sig1_2=W_ParamConfidenceInterval[1]
		// plot line
		String fit2Str="fit_"+y2Str

		SetScale/I x xl,xr,"",$fit2Str
		wave wf2=$fit2Str
		wf2=a0_2+a1_2*x
		////////////////////////
		
		// print results
		variable E_d=(a0_2-a0_1)/(a1_1-a1_2)
		variable hplanck=6.626007E-34
		variable eVJ=1.6021765E-19
		variable avgslope=(abs(a1_1)+abs(a1_2))*0.5
		variable deltaavgslope=0.5*(sig1_2+sig1_1)
		variable VF=1/(hplanck*avgslope*calib*0.5*1E10/eVJ) //0.0028 for Ir001
		variable deltaVF=1/(hplanck*calib*0.5*1E10/eVJ)*deltaavgslope/(avgslope)^2 
		// print for debug

		string intErrStr
		if(intercepterror==1)
		intErrStr = "no"
		else
		intErrStr = "yes"
		endif
		
		// error on E_D
	
		variable err_E_d=sqrt( (sig0_2^2+sig0_1^2) /  (abs(a1_1-a1_2))^2 + (intercepterror-1) * (sig1_2^2+sig1_1^2) * ((a0_2-a0_1)/(a1_1-a1_2)^2)^2 )
		string  msgStr="The Dirac point is located at: "+num2Str(E_d)+" pm "+num2Str(err_E_d)+"\rFermi velocity is: "+num2Str(VF)+" pm "+num2str(deltaVF) + "\rintercept error: " + intErrStr + " from wave: " + ref
		make/N=2/O edw
		edw=E_d
		String wfpStr="WF"+dfStr+"_P"
		variable leftxWF=leftx($wfpStr)
		variable rightxWF=rightx($wfpStr)
		//SetScale/I x leftxWF,rightxWF,"",edw
		TextBox/C/N=text1/A=RB msgStr
		// append on waterfall
		//if(opMode==1)
		//ErrorBars $y1Str Y,wave=($errStr1,$errStr1)
		//ErrorBars $y2Str Y,wave=($errStr2,$errStr2)
		//ModifyGraph mode($y1Str)=4,marker($y1Str)=17,msize($y1Str)=1.2
		//ModifyGraph mode($y2Str)=4,marker($y2Str)=17,msize($y2Str)=1.2
		//endif
		String waterfallStr = "WF"+dfStr
		DRC_lineToWaterfallVert(waterfallStr,fit2Str)
		DRC_lineToWaterfallVert(waterfallStr,fit1Str)
		//DRC_lineToWaterfallBottom(waterfallStr,"edw")
		//ModifyGraph rgb=(65280,0,0)
		ModifyGraph width=0
		TextBox/C/N=text1/A=RB msgStr
		
	SetDataFolder root:SIS
	wave DM
	M = M - 1
	DM[1][M] = E_d
	DM[2][M] = err_E_d
	DM[3][M] = VF
	DM[4][M] = deltaVF	
		
	SetDataFolder root:$(dfStr)
		
	endif
endif
end

///////------------------///////------------------///////------------------///////------------------///////------------------///////------------------///////------------------///////

Function DRC_LineRrange()
	String dfStr=SIS_getDataFolderName()
	SetDataFolder root:$(dfStr)
	String winStr=SIS_getWinName()
	variable m, q, mc //relative variable
	variable F //logic variable
	variable/G rC //position of the center between the two peak
SIS_PauseForCursors(winStr,"Put Crs on the LEFT")

m = (vcsr(A) - vcsr(B))/(hcsr(A) - hcsr(B))
q = (vcsr(A) + vcsr(B) - (hcsr(A) + hcsr(B))*m)/2

F=1 //logic parameter F=1 means LEFT range
print "F==", F, "m:", m, "q", q
DRC_Range(m,q,F)

SIS_PauseForCursors(winStr,"Put Crs on the RIGHT")

m = (vcsr(A) - vcsr(B))/(hcsr(A) - hcsr(B))
q = (vcsr(A) + vcsr(B) - (hcsr(A) + hcsr(B))*m)/2

F=2 //logic parameter F=2 means RIGHT range
print "F==", F, "m:", m, "q", q
DRC_Range(m,q,F)

SIS_PauseForCursors(winStr,"Put Cr A on the CENTER")
mc = hcsr(A)
rC = mc
print "F==", F, "m centrale", mc
F=3 //logic parameter F=3 means CENTER range
DRC_Range(mc,q,F)


wave xrangeL, yrangeL, xrangeR, yrangeR, xrangeC, yrangeC
		string wfpStr="WF"+dfStr+"_P"
		string xwave = nameofwave(xrangeL) // different way to plot result
		string ywave = nameofwave(yrangeL)
		string waterfallStr = "WF"+dfStr
		DRC_append(waterfallStr,ywave, xwave)
		doUpdate
		xwave = nameofwave(xrangeR)
		ywave = nameofwave(yrangeR)
		DRC_append(waterfallStr,ywave, xwave)
		doUpdate
		xwave = nameofwave(xrangeC)
		ywave = nameofwave(yrangeC)
		DRC_append(waterfallStr,ywave, xwave)
		doUpdate
		
		ModifyGraph rgb(yrangeR)=(0,15872,65280), lsize(yrangeR)=1.2
		ModifyGraph rgb(yrangeL)=(16384,65280,16384), lsize(yrangeL)=1.2
		ModifyGraph rgb(yrangeC)=(65280,49152,16384), lsize(yrangeC)=1.2

end

///////------------------///////------------------///////------------------///////------------------///////------------------///////------------------///////------------------///////

Function DRC_Range(m,q,F)
	variable m,q,F

	String dfStr=SIS_getDataFolderName()
	SetDataFolder root:$(dfStr)
	String winStr=SIS_getWinName()
	String stv = WaveList("STV*",";","") //WaveList returns a LIST of waves, I have to select the wave which I want
	stv = StringFromList(0, stv) // StringFromList used to pick up a name from a list
	String imgNum = WaveList("ImageNum_*",";","")
	imgNum = StringFromList(0, imgNum)

	variable i
	variable Ynum
	variable ymin, ymax, ImgMax

	wavestats/Q $stv 
	ymin = V_min
	ymax = V_max
	
	wavestats/Q $imgNum
	ImgMax = V_max

	if(vcsr(A)<=vcsr(B))
		variable xstart = hcsr(A), ystart = vcsr(A)
		variable xstop = hcsr(B), ystop = vcsr(B)
	endif
	if(vcsr(A)>vcsr(B))
		xstart = hcsr(B)
		ystart = vcsr(B)
		xstop = hcsr(A)
		ystop = vcsr(A)
	endif

ystart = ymin //relative variable
ystop = ymax //relative variable
Ynum = ImgMax + 1

	make/o/n=(Ynum) xrangeL, yrangeL //left
	make/o/n=(Ynum) xrangeR, yrangeR //right
	make/o/n=(Ynum) xrangeC, yrangeC //center
	make/o/n=(Ynum) xrange, yrange //center

variable delta_y = (ystop - ystart)/Ynum
variable increment = ystart - delta_y  //increment variable, set the starting point

	// line in relative coordinates
	for(i=0;i<Ynum;i+=1)
		increment += delta_y
		yrange[i] = increment
		xrange[i]=(yrange[i] - q)/m
	endfor
		
if(F==1)
	for(i=0;i<Ynum; i+=1)
		if (xrange[i]<xstart)
			xrange[i] = xstart
		endif	
	endfor
	xrangeL = xrange 
	yrangeL = yrange 	
endif

if(F==2)
	for(i=0;i<Ynum; i+=1)
		if (xrange[i]>xstart)
		 	xrange[i] = xstart
		 endif	
	endfor
	 xrangeR = xrange
	 yrangeR = yrange
endif

if(F==3)
	xrangeC = m
	yrangeC = yrange
endif

End

///////------------------///////------------------///////------------------///////------------------///////------------------///////------------------///////------------------///////

Function DRC_fitSeriesWithRange()
	// data folder and stack
	String dfStr=SIS_getDataFolderName()
	SetDataFolder root:$(dfStr)
	// waves
	String wfStr=SIS_getImageStackName()
	String winStr=SIS_getWinName()
	String xStr=winStr+"_P"
	// globals
	wave/T dsf_text=root:$(dfStr):dsf_text
	wave dsf_coef=root:$(dfStr):dsf_coef
	wave dsf_hold=root:$(dfStr):dsf_hold
	wave/T dsf_cnstr=root:$(dfStr):dsf_cnstr
	wave/T dsf_fit_cnstr=root:$(dfStr):dsf_fit_cnstr
	SVAR holdStr=root:$(dfStr):holdStr
	NVAR fittype=root:$(dfStr):fittype
	NVAR sigmaDetector=root:SIS:sigmaDetector
	FIT_makeHoldStr()
	// pause for user input
	SIS_PauseForCursors(winStr,"Adjust crs A and B")	
	// cursors
	variable ff,tf,fh,tt
	if (strlen(CsrInfo(A))==0)
		ff=0
		fh=0
	else
		ff=qcsr(A)
		fh=pcsr(A)
	endif
	if (strlen(CsrInfo(B))==0)
		tf=dimSize($wfStr,1)-1
		tt=dimSize($wfStr,1)-1
	else
		tf=qcsr(B)
		tt=pcsr(B)
	endif
	// input 
	Variable fromFrame=ff
	Prompt fromFrame, "From Frame"
	Variable toFrame=tf
	Prompt toFrame, "to Frame"
	String tmpHoldStr=holdStr
	Prompt tmpHoldStr, "hold"
	Variable mode=fittype
	Prompt mode, "Function type", popup "Doniach-Sunjic;Gaussian;Lorentzian;Sigmoid;"
	Variable shirley=1
	Prompt shirley, "Shirley background", popup "keep;remove;"
	Variable npntsbkg=6
	Prompt npntsbkg, "n points for Shirley background"
	Variable sigmaDetectorSystem=sigmaDetector
	Prompt sigmaDetectorSystem, "Detector system sigma;"
	doPrompt "input fit series WF ", fromFrame,toFrame,tmpHoldStr,mode,shirley,npntsbkg,sigmaDetectorSystem //,fromhere
	// if ok
	if (V_flag==0)  
		sigmaDetector = sigmaDetectorSystem
		fittype=mode
		// prepare for fit and create the results wave
		FIT_makeCnstrStr(tmpHoldStr)
		duplicate/o dsf_coef w_dsf_coef 
		variable nq=dimsize($wfStr,1)
		variable n_of_coefficients=(dsf_coef[0]+1)*5
		make/n=(nq,n_of_coefficients)/o fit_results=NaN
		make/n=(nq,n_of_coefficients)/o fit_errors=NaN
		// new graph
		variable i=fromFrame
		imageTransform/G=(i) getCol $wfStr
		duplicate/o $xStr tmpx
		redimension/n=(numpnts($xStr)-1) tmpx
		SIS_graphToFront("WF_FIT","W_ExtractedCol","tmpx")
		SetAxis/A bottom
		// loop
		i=fromFrame
		variable j=0
		variable incr=1
		if (fromFrame>toFrame)
			incr=-1
		endif
		String messageStr
		wave W_ExtractedCol,w_sigma
		
			String stv_STR = WaveList("STV*",";","")
			stv_STR = StringFromList(0, stv_STR) 
			variable numStv = dimSize($stv_STR,0)
			wave wStv = $stv_STR
			variable m_stv = wStv[numStv -1] - wStv[0]
			//m_stv > 0 means: from 34 eV to 38 eV
			//m_stv < 0 means: from 38 eV to 34 eV
			print "m_stv", m_stv
			print "numStv", numStv
			
			variable rl, rr
			wave xrangeL, xrangeR

		for (j=min(fromFrame,toFrame);j<=max(fromFrame,toFrame);j+=1)
			imageTransform/G=(i) getCol $wfStr
			// qui estraggo dall'onda gli estremi dell'intervallo, devo fare in modo che non dipendano da come  stato acquisito lo spettro, e.g. da 38 eV a 34 eV, o viceversa da 34 eV a 38 eV, per esempio.
				
				if(m_stv < 0)
					 rl = round(xrangeL[numStv - i]) 					
					 rr = round(xrangeR[numStv - i]) 	
					 //print "m_stv < 0", "rl", rl, "rr", rr, "i", i
				else
					 rl = round(xrangeL[abs(-i)]) 
					 rr = round(xrangeR[abs(-i)]) 	
					 //print "m_stv > 0", "rl", rl, "rr", rr, "i", i
				endif				
			// errors
			
			duplicate/o W_ExtractedCol sigmaw
			if (sigmaDetectorSystem > 0)
				sigmaw=sigmaDetectorSystem
			else
				sigmaw=sqrt(sigmaw)
			endif
			
			//
			
			messageStr=num2str(abs(i-fromframe))+" out of "+num2str(max(fromFrame,toFrame)-min(fromFrame,toFrame))
				TextBox/C/N=text0/A=RT messageStr
				DoUpdate
					if (shirley == 2)
						FIT_removeShirleyFromProfile("W_ExtractedCol","tmpx",npntsbkg)
					endif
				DoUpdate
			// do the fit
			
			if (mode == 1)
				if (strsearch(dsf_text[6],"Doublet",0)==-1)
					FuncFit/H=(tmpHoldStr)/Q/G/NTHR=0 FIT_multiPeakDS w_dsf_coef W_ExtractedCol[rl,rr] /X=tmpx /D /R /C=dsf_fit_cnstr/W=sigmaw/I=1/F={0.683000, 4}/NWOK //fromhere
				else
					FuncFit/H=(tmpHoldStr)/Q/G/NTHR=0 FIT_multiDoubletDS w_dsf_coef W_ExtractedCol[rl,rr] /X=tmpx /D /R /C=dsf_fit_cnstr/W=sigmaw/I=1/F={0.683000, 4}/NWOK //fromhere
				endif
			endif
			if (mode == 2)
				FuncFit/H=(tmpHoldStr)/Q/G/NTHR=0 FIT_multiPeakGauss w_dsf_coef W_ExtractedCol[rl,rr] /X=tmpx /D /R /C=dsf_fit_cnstr/W=sigmaw/I=1/F={0.683000, 4}/NWOK //fromhere
			endif
			if (mode == 3)
				FuncFit/H=(tmpHoldStr)/Q/G/NTHR=0 FIT_multiPeakLor w_dsf_coef W_ExtractedCol[rl,rr] /X=tmpx /D /R /C=dsf_fit_cnstr/W=sigmaw/I=1/F={0.683000, 4}/NWOK //fromhere
			endif
			if (mode==4)
				FuncFit/H=(tmpHoldStr)/G/NTHR=0 FIT_sigmoid w_dsf_coef W_ExtractedCol[rl,rr] /X=tmpx /D /R /C=dsf_fit_cnstr/W=sigmaw/I=1/F={0.683000, 4}/NWOK //fromhere
			endif
			// store the results using putcol
			imageTransform/G=(i)/D=w_dsf_coef putrow fit_results
			imageTransform/G=(i)/D=w_sigma putrow fit_errors
			i+=incr
		endfor
		//edit results
		DoWindow/K WF_FIT
		String tableStr="RT"+dfStr
		//SIS_tableToFront(tableStr,"fit_results")	
	endif
End

///////------------------///////------------------///////------------------///////------------------///////------------------///////------------------///////------------------///////

Function DRC_fitSeriesWRSinglePeak()
	//WR: With Range, for a single peak
	// data folder and stack
	String dfStr=SIS_getDataFolderName()
	SetDataFolder root:$(dfStr)
	// waves
	String wfStr=SIS_getImageStackName()
	String winStr=SIS_getWinName()
	String xStr=winStr+"_P"
	// globals
	String stv_STR = WaveList("STV*",";","") //WaveList returns a LIST of waves, I have to select the wave which I want
	stv_STR = StringFromList(0, stv_STR) // StringFromList used to pick up a name from a list
	wave/T dsf_text=root:$(dfStr):dsf_text
	wave dsf_coef=root:$(dfStr):dsf_coef
	wave dsf_hold=root:$(dfStr):dsf_hold
	wave/T dsf_cnstr=root:$(dfStr):dsf_cnstr
	wave/T dsf_fit_cnstr=root:$(dfStr):dsf_fit_cnstr
	wave cf
	SVAR holdStr=root:$(dfStr):holdStr
	SVAR hold_sp=root:$(dfStr):hold_sp
	string/G hold_sp = "1000011000"
	NVAR fittype=root:$(dfStr):fittype
	NVAR rC=root:$(dfStr):rC // Center position
	NVAR sigmaDetector=root:SIS:sigmaDetector
	NVAR nGp = root:$(dfStr):nGp
	variable np //number of the peak that I want to fit

variable numStv = dimSize($stv_STR,0)
	
	holdStr = hold_sp
	FIT_makeHoldStr()
	// pause for user input
	SIS_PauseForCursors(winStr,"Adjust crs A and B")	
	// cursors
	variable ff,tf
	if (strlen(CsrInfo(A))==0)
		ff=0
	else
		ff=qcsr(A)
	endif
	if (strlen(CsrInfo(B))==0)
		tf=dimSize($wfStr,1)-1
	else
		tf=qcsr(B)
	endif
	// input 
	Variable fromFrame=ff
	Prompt fromFrame, "From Frame"
	Variable toFrame=tf
	Prompt toFrame, "to Frame"
	Variable mode = 1 //mode = 1, the paeks are fitted with relative constrains on position
	Prompt mode, "Function type", popup "Fit with RATIO constrains"
	Variable reFit = 1
	Prompt reFit, "First fit / Re Fit", popup "FIRST fit; RE-fit"
	variable rt1 = 20
	prompt rt1, "variation of the gaussian peaks position(%)"
	variable rt2 = 20
	prompt rt2, "variation of the gaussian width (%)"
	string Local_hold_sp = hold_sp
	prompt Local_hold_sp, "hold"
	Variable sigmaDetectorSystem=sigmaDetector
	Prompt sigmaDetectorSystem, "Detector system sigma;"
	doPrompt "input fit series WF with Gaussian", fromFrame,toFrame,mode,reFit, rt1, rt2,Local_hold_sp,sigmaDetectorSystem 
	// if ok
	if (V_flag==0)  
		sigmaDetector = sigmaDetectorSystem
		fittype=mode
		
		// prepare for fit and create the results wave
		duplicate/o dsf_coef w_dsf_coef 
		variable nq=dimsize($wfStr,1)
		variable n_of_coefficients=(dsf_coef[0]+1)*5

		variable i=fromFrame
		imageTransform/G=(i) getCol $wfStr
		duplicate/o $xStr tmpx
		redimension/n=(numpnts($xStr)-1) tmpx
		SIS_graphToFront("WF_FIT","W_ExtractedCol","tmpx")
		SetAxis/A bottom
		// loop
		i=fromFrame
		variable j=0
		variable incr=1
		if (fromFrame>toFrame)
			incr=-1
		endif
		String messageStr
		wave W_ExtractedCol,w_sigma
		
///////////////////// cycles for  /////////////////////		

			wave xrangeL, xrangeR, dsf_cnstr_sp
			wave FRG

			variable cl= rC + 5,  cr= rC - 5
			
			wave wStv = $stv_STR
			variable m_stv = wStv[numStv -1] - wStv[0]
			variable rl, rr
			
			np= 1
			DRC_relativeConstrain(np,i,rt1, rt2,reFit)			
	
			if(np == 1)
			string StrG = "FitResultsGaussian_" + num2str(np)
			wave fitG = $StrG

				for (j=min(fromFrame,toFrame);j<=max(fromFrame,toFrame);j+=1)
					
					if(mode==1)
						DRC_relativeConstrain(np,i,rt1, rt2,reFit)
					endif
					//edit cf
					imageTransform/G=(i) getCol $wfStr
					//
					if(m_stv < 0)
						 rl = round(xrangeL[numStv - i]) 					
					else
						 rl = round(xrangeL[abs(-i)]) 
					endif
										
					// errors
					duplicate/o W_ExtractedCol sigmaw
					if (sigmaDetectorSystem > 0)
						sigmaw=sigmaDetectorSystem
					else
						sigmaw=sqrt(sigmaw)
					endif
						//
					messageStr=num2str(abs(i-fromframe))+" out of "+num2str(max(fromFrame,toFrame)-min(fromFrame,toFrame))
					TextBox/C/N=text0/A=RT messageStr
					DoUpdate
					//LEFT peak
							FuncFit/H=(local_hold_sp)/Q/G/NTHR=0 FIT_multiPeakGauss cf W_ExtractedCol[rl,cl] /X=tmpx /D /R /C=dsf_cnstr_sp /W=sigmaw/I=1/F={0.683000, 4}/NWOK
							fitG[i][0] = cf[9] // I'm putting the peak position in the matrix
							fitG[i][1] = w_sigma[9] // I'm putting the error on peak position in the matrix
							fitG[i][2] = cf[7] // I'm putting the sigma value in the matrix
					if(reFit == 1)			
							FRG[i][0] = 	fitG[i][0]				
							FRG[i][1] = 	fitG[i][1]	
							FRG[i][2] = 	fitG[i][2]	
					endif
						i+=incr
						
					endfor
				endif
				
		i=fromFrame // restart the sum index
		np = 2
				
		if(np == 2)
			StrG = "FitResultsGaussian_" + num2str(np)
			wave fitG = $StrG
			
				for (j=min(fromFrame,toFrame);j<=max(fromFrame,toFrame);j+=1)
				
					if(mode==1)
						DRC_relativeConstrain(np,i,rt1, rt2,ReFit)
					endif
					
					imageTransform/G=(i) getCol $wfStr
					
					if(m_stv < 0)
						 rr = round(xrangeR[numStv - i]) 					
					else
						 rr = round(xrangeR[abs(-i)]) 	
					endif
						
					duplicate/o W_ExtractedCol sigmaw
					if (sigmaDetectorSystem > 0)
						sigmaw=sigmaDetectorSystem
					else
						sigmaw=sqrt(sigmaw)
					endif
						//
					messageStr=num2str(abs(i-fromframe))+" out of "+num2str(max(fromFrame,toFrame)-min(fromFrame,toFrame))
					TextBox/C/N=text0/A=RT messageStr
					DoUpdate
					//RIGHT peak
	
							FuncFit/H=(local_hold_sp)/Q/G/NTHR=0 FIT_multiPeakGauss cf W_ExtractedCol[rc,rr] /X=tmpx /D /R /C=dsf_cnstr_sp /W=sigmaw/I=1/F={0.683000, 4}/NWOK
							fitG[i][0] = cf[9] // I'm putting the peak position in the matrix
							fitG[i][1] = w_sigma[9] // I'm putting the error on peak position in the matrix
							fitG[i][2] = cf[7] // I'm putting the sigma value in the matrix
					if(reFit == 1)			
							FRG[i][3] = 	fitG[i][0]				
							FRG[i][4] = 	fitG[i][1]	
							FRG[i][5] = 	fitG[i][2]	
					endif		
					i+=incr				
				endfor
			endif
			
		endif
		
	//edit results
	DoWindow/K WF_FIT

end

///////------------------///////------------------///////------------------///////------------------///////------------------///////------------------///////------------------///////

Function DRC_extractResultsSP()
	// data folder
	String dfStr=SIS_getDataFolderName()
	SetDataFolder root:$(dfStr)
	// waves
	String winStr=SIS_getWinName()
	// globals
	wave dsf_coef=root:$(dfStr):dsf_coef
	wave dsf_hold=root:$(dfStr):dsf_hold
	//NVAR dsf_npeaks=root:$(dfStr):dsf_npeaks
	SVAR holdStr=root:$(dfStr):holdStr	
	wave fit_results=root:$(dfStr):fit_results
	wave fit_errors=root:$(dfStr):fit_errors	
	//select the mode for extraction of fit results	

	variable mode = 2
	prompt mode,"Extract results from:", popup "FitWF_WithRange;FitWF_WRSinglePeak"
	String xStr
	//Prompt xStr, "enter x-axis wave",popup WaveList("WF*_*Q",";","")
	//variable Displ_err
	//prompt Displ_err, "Display error", popup "no;yes"
	doprompt "Select mode operation of extract results", mode//, xStr//,Displ_err
	
	string strList = WaveList("WF*_*Q",";","")
	xStr = StringFromList(0, strList)
	
			variable np=dimsize($xStr,0) - 1
			variable i=0,j=0
			String tmpStr//=""
			String errStr//=""
			Variable parameter = 5 // set parameter to ==> peak position
			string namew
	// input
if (V_flag==0)  

		//Prompt parameter, "Parameter", popup "Lorentzian width; Asymmetry; Gaussian width; peak intensity; peak position"
		//doPrompt "series fit extract parameter", parameter
		//if (V_flag ==0)
			// extract and display
		
		
				for (i=1;i<=dsf_coef[0];i+=1)
					j=5*i+parameter-1
								
					if(mode==1)	
						String graphStr="FR"+dfStr
						tmpStr=graphStr+"_"+num2Str(j)
						errStr="ER"+dfStr+"_"+num2Str(j)
						make/N=(np)/o $tmpStr=NaN,$errStr=NaN
						wave w = $tmpStr
						wave we = $errStr	
						w=fit_results[p][j]
						we=fit_errors[p][j]
					endif
		
					if(mode == 2)
						graphStr="rt_FR"+dfStr
						parameter = 5
						tmpStr= graphStr+"_"+num2Str(j)
						errStr="rt_" + "ER"+dfStr+"_"+num2Str(j)
						make/N=(np)/o $tmpStr=NaN,$errStr=NaN

						wave w=$tmpStr
						wave we=$errStr	
		
						namew =  "FitResultsGaussian_" + num2str(i)
	
						wave wc = $namew
				
						w=wc[p][0]
						we=wc[p][1]
					
					endif
				
					
					String axis=FIT_graphToFront(graphStr,tmpStr,xStr,parameter)
				
				
					Label $axis "\\F'Arial'\\Z18Intensity (arb. u.)"
					ModifyGraph lblPosMode=1
					ModifyGraph freePos($axis)=0
					ShowInfo
					Label bottom "\\F'Arial'\\Z18Start Voltage (eV)"
					ModifyGraph fSize=12
					ModifyGraph lsize($tmpStr)=1.25 //lsize:line size
				
					//ErrorBars $tmpStr Y,wave=($errStr,$errStr)
					//ModifyGraph mode($tmpStr)=4,marker($tmpStr)=17,msize($tmpStr)=1.2
				
					ModifyGraph width=0	
					
					//if(mode==1)	
						//ModifyGraph mode($tmpStr)=4,marker($tmpStr)=8, msize($tmpStr)=1.2
 						//ModifyGraph msize=1.2
					//endif
					if (parameter<4)
						Label $axis "\\F'Arial'\\Z18FWHM (eV)"
					elseif (parameter==4)
						Label $axis "\\F'Arial'\\Z18Intensity (arb. u.)"
					elseif (parameter==5) 
						Label $axis "\\F'Arial'\\Z18Peak Position (pixel)"
						SetAxis Left5 25,160
				endif
			endfor

	
		//endif
	
endif
End

///////------------------///////------------------///////------------------///////------------------///////------------------///////------------------///////------------------///////

Function DRC_displayAllDiracEnergy()

String dfStr=SIS_getDataFolderName()

setDataFolder root:SIS

wave DM 
NVAR coneNumber = root:SIS:coneNumber
NVAR EaV = root:SIS:EaV
NVAR sigma_ed = root:SIS:sigma_ed
SVAR fName = root:SIS:fName
NVAR sigma_fV = root:SIS:sigma_fV
NVAR fV_aV = root:SIS:fV_aV
variable n //real number of the cone in the matrix
variable edShift //difference between dirac energy and fermi level
variable err_edShift // error on edShift calculated as the sum of the two errors
n = coneNumber
variable ymin, ymax //ymin & ymax are used below to display the waves
make/O/N=(6) temp = NaN, cnw = NaN
variable ex
string textb

variable mode = 3, i //sum index
prompt mode, "What do you want to display?" popup "Display all ED;Display all FV;Display all ED + VF"
doprompt "Select the operation mode", mode

if(v_flag==0)
	variable mor = mode
	
	if(mor==3)
		mode=1
	endif
	
	if(mode==1) //Display Dirac Energies
		make/O/N=(6) cvw = NaN, cew = NaN //cnw:cone number wave, cvw:cone value wave, cew: cone error wave
		DoWindow/K DiracEnergy
		wave wEav
	 		for(i=0;i<6;i+=1)
	 			if(DM[0][i]!=0)
	 				cnw[i] = DM[0][i]
	 			endif
	 			if(DM[7][i]!=0)
			 		cvw[i] = DM[7][i]
				 endif
			 	if(DM[8][i]!=0) //!= means "different from"
			 		cew[i] = DM[8][i]
				 endif
		 	endfor
		
		display/N=DiracEnergy cvw vs cnw	
		//set the graph range using a temporary wave, which will be killed at the end of the procedure
		for(i=0;i<6;i+=1)
			temp[i] = cvw[i] + cew[i]
		endfor
		wavestats/Q temp
		ymax = V_max + 0.05

		for(i=0;i<6;i+=1)
			temp[i] = cvw[i] - cew[i]
		endfor
		wavestats/Q temp
		ymin = V_min - 0.05
		
		SetAxis left ymin,ymax	
		ModifyGraph mode=3,marker=19,lsize=1.2,rgb=(0,0,65280)
		ErrorBars cvw Y,wave=(cew,cew)
		
		ex = WaveExists(wEav)
		if(ex==1)
			appendtograph wEav vs cnw
			ModifyGraph lsize=1.2,lstyle(wEaV)=2	
		endif
		textb = fname + "\r\f00\Z10" + "w. average: " + num2str(EaV) + " pm " + num2str(sigma_ed)
		Label bottom "\\Z12\\f01Number of the cone (#)"
		Label left "\\f01\\Z12E\\BD\\M\\Z12 - E\\BF \\M\\Z12(eV)"
		Legend/C/N=text0/J/E=0/A=RT "\\s(cvw) Experimental points\t\r\\s(wEaV) Weighted average"
		TextBox/C/N=text1/A=LT "\\f01\\Z14" + textb
		ModifyGraph width=350, height=200, grid(left)=2
		
	endif
	
	if(mor==3)
		mode=2
	endif
	
	if(mode==2) //Display Fermi Velocities
		make/O/N=(6) vvw = NaN, vew = NaN //cnw:cone number wave, cvw:cone value wave, cew: cone error wave
		DoWindow/K FermiVelocities
		wave w_fVaV
	 		for(i=0;i<6;i+=1)
	 			if(DM[0][i]!=0)
	 				cnw[i] = DM[0][i]
	 			endif
	 			if(DM[7][i]!=0)
			 		vvw[i] = DM[3][i]
				 endif
			 	if(DM[8][i]!=0) //!= means "different from"
			 		vew[i] = DM[4][i]
				 endif
		 	endfor
		
		display/N=FermiVelocities vvw vs cnw	
		//set the graph range using a temporary wave, which will be killed at the end of the procedure
		for(i=0;i<6;i+=1)
		temp[i] = vvw[i] + vew[i]
		endfor
		wavestats/Q temp
		ymax = V_max + 0.05

		for(i=0;i<6;i+=1)
		temp[i] = vvw[i] - vew[i]
		endfor
		wavestats/Q temp
		ymin = V_min - 0.05
		
		SetAxis left ymin,ymax	
		ModifyGraph mode=3,marker=19,lsize=1.2,rgb=(0,0,65280)
		ErrorBars vvw Y,wave=(vew,vew)
		
		ex = WaveExists(w_fVaV)
		if(ex==1)
			appendtograph w_fVaV vs cnw
			ModifyGraph lsize=1.2,lstyle(w_fVaV)=2	
		endif
		Label bottom "\\Z12\\f01Number of the cone (#)"
		Label left "\\f01\\Z12Fermi Velocities (m/s)"
		Legend/C/N=text0/J/E=0/A=RT "\\s(vvw) Experimental points\t\r\\s(w_fVaV) Weighted average"
		textb = fname + "\r\f00\Z10" + "w. average: " + num2str(fV_aV) + " pm " + num2str(sigma_fV)
		TextBox/C/N=text1/A=LT "\\f01\\Z14" + textb
		ModifyGraph width=350, height=200, grid(left)=2,notation(left)=1
		
	endif			
killwaves temp
endif

//SetDataFolder root:$(dfStr)

End

///////------------------///////------------------///////------------------///////------------------///////------------------///////------------------///////------------------///////

Function DRC_GfitInitialize()
	String dfStr=SIS_getDataFolderName()
	SetDataFolder root:$(dfStr)	
	wave/T dsf_cnstr
	wave dsf_coef,dsf_hold
	NVAR fittype = root:$(dfStr):fittype
	
	string k7 = "K7"
	string k12 = "K12"
	dsf_cnstr[7] = k7 + " > " +  k12
	dsf_cnstr[12] = k7 + " < " + k12
	dsf_hold[3] = 0 //if I forgot to do it manually
	dsf_hold[4] = 0
		
	variable med
	med = (dsf_coef[7] + dsf_coef[12])/2
	dsf_coef[7] = med
	dsf_coef[12] = med
	
	fittype = 2
	
FIT_fitProfile()

End

///////------------------///////------------------///////------------------///////------------------///////------------------///////------------------///////------------------///////

Function DRC_lineToWaterfallVert(graphNameStr,waveNameStr)
	String graphNameStr
	String waveNameStr
	graphNameStr= SIS_removeQuotes(graphNameStr)
	Dowindow $graphNameStr
	if (V_flag==0)
		Display
		DoWindow/C $graphNameStr
		appendToGraph/VERT $waveNameStr 
		Legend/C/N=text0/A=LT
		ModifyGraph rgb($waveNameStr)=(abs(enoise(65280)),abs(enoise(65280)),abs(enoise(65280)))
		ModifyGraph width=240,height={Aspect,1}
		ModifyGraph mirror=1
			else
		DoWindow/F $graphNameStr
		String empty=WaveList(waveNameStr, ";", "WIN:"+graphNameStr)
		if (strlen(empty)==0)
			appendToGraph/VERT $waveNameStr
			ModifyGraph rgb($waveNameStr)=(abs(enoise(65280)),abs(enoise(65280)),abs(enoise(65280)))
		endif
	endif
end

///////------------------///////------------------///////------------------///////--------PROCEDURES-------///////------------------///////------------------///////------------------///////

Function DRC_AllStoreMatrix(M)
		variable M // global variable, like a INPUT
		variable i // local variable
		
		variable ex = exists("DM")
			
		if(ex==0)
			DoWindow/K StorageMatrix
			make/O/n=(9,M) DM //Dirac Matrix
			make/O/n=9/T labelsDM
			DM = 0
			labelsDM[0] = "Number of the cone"
			labelsDM[1] = "Dirac Position"
			labelsDM[2] = "Error on Dirac Position "
			labelsDM[3] = "Fermi Velocity "
			labelsDM[4] = "Error on Fermi Velocity "
			labelsDM[5] = "Fermi Level "
			labelsDM[6] = "Error on Fermi Level "
			labelsDM[7] = "Dirac Energy"
			labelsDM[8] = "Error on Dirac Energy "
	
			for(i=0;i<M;i+=1) //i<M Igor stops at M-1, and starts from 0
				DM[0][i] = i + 1
			endfor
			edit/N=StorageMatrix labelsDM, DM
		else
			DoWindow/K StorageMatrix
			edit/N=StorageMatrix labelsDM, DM
		endif
End

/////===================/////===================/////===================/////===================/////===================/////

Function DRC_FermiMatrix(M)
			variable M
			variable N = 4, i
			variable ex = exists("FM")
			
			if(ex==0)
				//prompt N, "Number of Fermi edges"
				//doprompt "cCreation of storage matrix for weighted average of Fermi Levels", N
				N = N*2 + 1 //in the matrix I want to add also errors and a column with the number of cones
				DoWindow/K FermiMatrices
				make/O/n=(M,N) FM //Fermi Matrix
				FM = 0	
				for(i=0;i<M;i+=1) //i<M Igor stops at M-1, and starts from 0
					FM[i][0] = i + 1
				endfor
				edit/N=FermiMatrices FM	
			else
				DoWindow/K FermiMatrices
				edit/N=FermiMatrices FM
			endif
			
End
/////===================/////===================/////===================/////===================/////===================/////
Function DRC_tempFM()
		
		variable ex = exists("LF")
		string name = "TemporaryFM"
		
			if(ex==0)
				make/O/N=(2) LF, RF, outLF, outRF //first cell is for the FL the second is for FWHM 
				make/O/N=(1) err_LF, err_RF, er_outLF, er_outRF
				DoWindow/K TemporaryFM
				edit/N=$name LF, err_LF, RF, err_RF, outLF, er_outLF, outRF, er_outRF
			else
				DoWindow/K TemporaryFM
				edit/N=$name LF, err_LF, RF, err_RF, outLF, er_outLF, outRF, er_outRF
			endif
			
End
/////===================/////===================/////===================/////===================/////===================/////
Function DRC_append(graphNameStr,ywave,xwave)
	String graphNameStr
	String ywave
	String xwave
	graphNameStr= SIS_removeQuotes(graphNameStr)
	Dowindow $graphNameStr
	if (V_flag==0)
		Display
		DoWindow/C $graphNameStr
		appendToGraph $ywave vs $ xwave 
		Legend/C/N=text0/A=LT
		ModifyGraph width=240,height={Aspect,1}
		ModifyGraph mirror=1
		ModifyGraph lsize(ywave)=1.4
	else
		DoWindow/F $graphNameStr
		String empty=WaveList(ywave, ";", "WIN:"+graphNameStr)
		if (strlen(empty)==0)
			appendToGraph $ywave vs $xwave
		endif
	endif
End

/////===================/////===================/////===================/////===================/////===================/////

Function DRC_DiracInizialize()
	variable operate	
	SetDataFolder root:SIS

	variable/G coneNumber
	variable sigma = 3 //Local variable for the sigma detector
	variable s = exists("sigmaDetector") //0 name not in use, 2 name of a numeric or string variable in the specified data folder.
		
		if(s==0)
			variable/G sigmaDetector //Global variable for the sigma detector
		else
			NVAR sigmadetector = root:SIS:sigmadetector
			sigma = sigmaDetector
		endif
		
		
	variable/G nGp // number of gaussian peaks in the dirac cones
	string/G fName
	variable num, ng = 2
	string filenameStr
	NVAR lastprowidth = root:SIS:lastprowidth
	
	conenumber += 1
	fileNameStr = fName
	num = coneNumber
	
		prompt num, "insert the cone number"
		prompt sigma, "sigma detector"
		prompt filenameStr, "insert the file name"
		doprompt "Inizialization of Dirac Procedures", num, sigma, fileNameStr
		
	if(V_flag==0)
		lastprowidth = 5
		fName = fileNameStr
		coneNumber = num
		sigmaDetector = sigma
		nGp = ng
		DRC_singlePeakMatrix(ng)
		FIT_Initialise()
		operate = 1
		return operate
	else
		conenumber -= 1
		operate = 2
		return operate
	endif
end

/////===================/////===================/////===================/////===================/////===================/////

Function DRC_Reset()
	String dfStr=SIS_getDataFolderName()

	variable sure = 1
	prompt sure, "are you sure to reset the waves??", popup "Yes;No"
	doPrompt "reset waves", sure
	
	SetDataFolder root:SIS
	wave LF, err_LF, RF, err_RF, outLF, er_outLF, outRF, er_outRF

	
	SetDataFolder root:$(dfStr)
	
	if(V_flag==0)	
		if(sure==1)
			LF = 0
			err_LF = 0
			RF = 0
			err_RF = 0
			outLF = 0
			er_outLF = 0
			outRF = 0
			er_outRF = 0
		
			wave FitResultsGaussian_1, FitResultsGaussian_2, FRG, cf, fit_results, fit_errors
			NVAR st_pcsrA_9 = root:$(dfStr):st_pcsrA_9
			NVAR st_pcsrB_9 = root:$(dfStr):st_pcsrB_9
			NVAR st_pcsrA_14 = root:$(dfStr):st_pcsrA_14
			NVAR st_pcsrB_14 = root:$(dfStr):st_pcsrB_14

			st_pcsrA_9 = NaN
			st_pcsrB_9 = NaN
			st_pcsrA_14 = NaN
			st_pcsrB_14 = NaN
	
	
			 FitResultsGaussian_1 = NaN
			 FitResultsGaussian_2 = NaN
			 FRG = NaN
			 cf = NaN
			 fit_results = NaN 
			 fit_errors = NaN
	 
			 FIT_Initialise()
		 endif
	endif
End

/////===================/////===================/////===================/////===================/////===================/////

Function DRC_two2onePeak(np)
variable np //is the number of the peak, two possible value: 1 & 2
variable i
wave dsf_coef,dsf_cnstr,cf
string nameC, c = "coeff", e = "sigma" //nameC: coefficient wave name. nameC: error wave name
		nameC = c + "_np_" + num2str(np)
		make/O/N=(2)/T dsf_cnstr_sp //_sp: single peak		

//I'm creating a new wave with constrains for only one peak
dsf_cnstr_sp[0] = "K7>0"
dsf_cnstr_sp[1] = "K8>0"
wave fit_results, fit_errors

	//peak one
		if(np==1)		
			cf = dsf_coef	
			cf[0] = 1
		endif
	
	//peak two
		if(np==2)	
			cf = dsf_coef	
			cf[0] = 1	
			cf[7] = dsf_coef[12]
			cf[8] = dsf_coef[13]
			cf[9] = dsf_coef[14]
		endif	 

end

/////===================/////===================/////===================/////===================/////===================/////

Function DRC_singlePeakMatrix(np)
variable np
	String dfStr=SIS_getDataFolderName()
	SetDataFolder root:$(dfStr)	
String stv = WaveList("STV*",";","") //WaveList returns a LIST of waves, I have to select the wave which I want
stv = StringFromList(0, stv) // StringFromList used to pick up a name from a list

variable N = 3
variable M = numpnts($stv), i 
for(i=1; i <= np; i += 1)
string namematrix = "FitResultsGaussian_" + num2str(i)
make/O/N=(M,N) $namematrix = NaN
make/O/N=(M,N*2) FRG = NaN //FitResultsGaussian: global matrix for the storage
make/O/N=(10) cf
endfor

End

/////===================/////===================/////===================/////===================/////===================/////

Function DRC_relativeConstrain(np,i, rt1, rt2,reFit)
variable np //is the number of the peak, two possible value: 1 & 2
variable i, rt1, rt2, reFit // rt1 & rt2 percentual ratio, reFit: logical variable, allows to re fit with the previuos coefficients
wave dsf_coef,dsf_cnstr,FRG, cf
		variable n = 6 //set the constrain number
		make/O/N=(n)/T dsf_cnstr_sp //_sp: single peak		
//I'm creating a new wave with constrains for only one peak
dsf_cnstr_sp[0] = "K7>0"
dsf_cnstr_sp[1] = "K8>0"

wave fit_results, fit_errors
variable ParN, j
//debug
variable PosPlus, PosMinus //constrains on the position
variable SigmaPlus, SigmaMinus //constrains on the position


//initialization
			cf = dsf_coef	
			cf[0] = 1
if(reFit == 1)
	//peak one
		if(np==1)	
			ParN = 9 //parN: parameter number
				cf[7] = fit_results[i][7]
				cf[8] = fit_results[i][8]
				cf[9] = fit_results[i][9]		
										
				PosMinus = cf[ParN]*(1 - 1*rt1/100)	
				PosPlus = cf[ParN]*(1 + 1*rt1/100)
				SigmaMinus = cf[7]*(1 - 1*rt2/100)	
				SigmaPlus = cf[7]*(1 + 1*rt2/100)	
					
				dsf_cnstr_sp[2] = "K"+ num2str(9) + ">" + num2str(PosMinus)
				dsf_cnstr_sp[3] = "K"+ num2str(9) + "<" + num2str(PosPlus)
				dsf_cnstr_sp[4] = "K"+ num2str(7) + ">" + num2str(SigmaMinus)
				dsf_cnstr_sp[5] = "K"+ num2str(7) + "<" + num2str(SigmaPlus)
				
				//print "np", np , dsf_cnstr_sp[2],dsf_cnstr_sp[3],dsf_cnstr_sp[4],dsf_cnstr_sp[5], i

		endif
	
	//peak two
		if(np==2)	
			ParN = 14
				cf[7] = fit_results[i][12]
				cf[8] = fit_results[i][13]
				cf[9] = fit_results[i][14]	

				PosMinus = cf[ParN - 5]*(1 - 1*rt1/100)	
				PosPlus = cf[ParN - 5]*(1 + 1*rt1/100)
				SigmaMinus = cf[7]*(1 - 1*rt2/100)	
				SigmaPlus = cf[7]*(1 + 1*rt2/100)	
				dsf_cnstr_sp[2] = "K"+ num2str(9) + ">" + num2str(PosMinus)
				dsf_cnstr_sp[3] = "K"+ num2str(9) + "<" + num2str(PosPlus)
				dsf_cnstr_sp[4] = "K"+ num2str(7) + ">" + num2str(SigmaMinus)
				dsf_cnstr_sp[5] = "K"+ num2str(7) + "<" + num2str(SigmaPlus)				
				
				//print "np", np , dsf_cnstr_sp[2],dsf_cnstr_sp[3],dsf_cnstr_sp[4],dsf_cnstr_sp[5], i

		endif	 
endif

if(reFit == 2)
	//peak one
		if(np==1)	
				cf[7] = FRG[i][2] //sigma #1 on FRG
				cf[8] = fit_results[i][8]
				cf[9] = FRG[i][0] //position #1 on FRG	
				PosMinus = cf[9]*(1 - 1*rt1/100) //position = cf[9]
				PosPlus = cf[9]*(1 + 1*rt1/100) //position = cf[9]
				SigmaMinus = cf[7]*(1 - 1*rt2/100) //sigma = cf[7]
				SigmaPlus = cf[7]*(1 + 1*rt2/100) //sigma = cf[7]
				dsf_cnstr_sp[2] = "K"+ num2str(9) + ">" + num2str(PosMinus)
				dsf_cnstr_sp[3] = "K"+ num2str(9) + "<" + num2str(PosPlus)
				dsf_cnstr_sp[4] = "K"+ num2str(7) + ">" + num2str(SigmaMinus)
				dsf_cnstr_sp[5] = "K"+ num2str(7) + "<" + num2str(SigmaPlus)
				
		endif
	
	//peak two
		if(np==2)	
				cf[7] = FRG[i][5] //sigma #2 on FRG
				cf[8] = fit_results[i][13]
				cf[9] = FRG[i][3]	//position #2 on FRG					
				PosMinus = cf[9]*(1 - 1*rt1/100) //position = cf[9]
				PosPlus = cf[9]*(1 + 1*rt1/100) //position = cf[9]
				SigmaMinus = cf[7]*(1 - 1*rt2/100) //sigma = cf[7]
				SigmaPlus = cf[7]*(1 + 1*rt2/100) //sigma = cf[7]
				dsf_cnstr_sp[2] = "K"+ num2str(9) + ">" + num2str(PosMinus)
				dsf_cnstr_sp[3] = "K"+ num2str(9) + "<" + num2str(PosPlus)
				dsf_cnstr_sp[4] = "K"+ num2str(7) + ">" + num2str(SigmaMinus)
				dsf_cnstr_sp[5] = "K"+ num2str(7) + "<" + num2str(SigmaPlus)				

		endif	 
endif

end

/////===================/////===================/////===================/////===================/////===================/////
